<?php
function fanspaysite_customize_register($wp_customize) {
	// Add a new section for FansPaysite Theme Options
	$wp_customize->add_section('fanspaysite_theme_options', array(
		'title'    => __('FansPaysite Theme', 'fanspaysite'),
		'priority' => 160, // Position in the Customizer sidebar
	));

	// Add a setting for the default theme mode
	$wp_customize->add_setting('fanspaysite_default_theme_mode', array(
		'default'           => 'light',
		'sanitize_callback' => 'fanspaysite_sanitize_theme_mode', // Function to sanitize the input
	));

	// Add a control for the default theme mode (radio buttons)
	$wp_customize->add_control('fanspaysite_default_theme_mode', array(
		'label'    => __('Default Theme Mode', 'fanspaysite'),
		'section'  => 'fanspaysite_theme_options',
		'type'     => 'radio',
		'choices'  => array(
			'light' => __('Light', 'fanspaysite'),
			'dark'  => __('Dark', 'fanspaysite'),
			'auto'  => __('Auto', 'fanspaysite'),
		),
		'description' => __('Default theme mode before user selects own preference.', 'fanspaysite'),
	));

	// Add a setting for showing/hiding the theme mode switcher
	$wp_customize->add_setting('fanspaysite_show_theme_mode_switcher', array(
		'default'           => 'yes',
		'sanitize_callback' => 'fanspaysite_sanitize_show_switcher', // Function to sanitize the input
	));

	// Add a control for showing/hiding the theme mode switcher (checkbox)
	$wp_customize->add_control('fanspaysite_show_theme_mode_switcher', array(
		'label'    => __('Show Frontend Mode Switcher', 'fanspaysite'),
		'section'  => 'fanspaysite_theme_options',
		'type'     => 'checkbox',
	));

	// Add a setting for the default image.
	$wp_customize->add_setting( 'default_post_thumbnail', array(
		'default' => get_template_directory_uri() . '/default.jpg', // Default image URL.
		'sanitize_callback' => 'esc_url_raw',
	) );

	// Add an image control to upload the default thumbnail.
	$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'default_post_thumbnail', array(
		'label'    => __( 'Default Post Thumbnail in List', 'fanspaysite' ),
		'section'  => 'fanspaysite_theme_options',
		'settings' => 'default_post_thumbnail',
	) ) );

	// Add settings and controls for post details display options
    $post_details = array(
        'display_title' => __('Display Post Title', 'fanspaysite'),
        'display_category' => __('Display Post Category', 'fanspaysite'),
        'display_tags' => __('Display Post Tags', 'fanspaysite'),
        'display_date' => __('Display Post Date', 'fanspaysite'),
        'display_author' => __('Display Post Author', 'fanspaysite'),
    );

    foreach ($post_details as $setting => $label) {
        // Add setting
        $wp_customize->add_setting($setting, array(
            'default'           => true,
            'sanitize_callback' => 'fanspaysite_sanitize_checkbox',
        ));

        // Add control
        $wp_customize->add_control($setting, array(
            'label'    => $label,
            'section'  => 'fanspaysite_theme_options',
            'type'     => 'checkbox',
        ));
    }


}
add_action('customize_register', 'fanspaysite_customize_register');

// Sanitize function for theme mode
function fanspaysite_sanitize_theme_mode($input) {
	$valid = array('light', 'dark', 'auto');
	if (in_array($input, $valid, true)) {
		return $input;
	}
	return 'light'; // Fallback to 'light' if input is not valid
}

// Sanitize function for showing/hiding the theme mode switcher
function fanspaysite_sanitize_show_switcher($input) {
	if ($input === 'yes' || $input === true) {
		return 'yes';
	}
	return 'no';
}

function fanspaysite_sanitize_checkbox($checked) {
    return ((isset($checked) && true == $checked) ? true : false);
}