<?php

//Icon Menus

function fanspaysite_enqueue_admin_scripts($hook) {
	// Only add to the nav-menus.php admin page.
	if ('nav-menus.php' !== $hook) {
		return;
	}
	// Enqueue Font Awesome
	wp_enqueue_style('font-awesome', get_template_directory_uri() . '/lib/fa/css/all.min.css');

	// Enqueue FontAwesome Icon Picker CSS
	wp_enqueue_style('fontawesome-iconpicker', get_template_directory_uri(). '/lib/fa-picker/css/fontawesome-iconpicker.min.css');

	// Enqueue FontAwesome Icon Picker JS
	wp_enqueue_script('fontawesome-iconpicker', get_template_directory_uri() . '/lib/fa-picker/js/fontawesome-iconpicker.min.js', array('jquery'), null, true);

	// Enqueue custom JS to initialize icon picker
	wp_enqueue_script('fanspaysite-icon-picker-init', get_template_directory_uri() . '/js/fa-picker.js', array('jquery', 'fontawesome-iconpicker'), null, true);
}
add_action('admin_enqueue_scripts', 'fanspaysite_enqueue_admin_scripts');

function fanspaysite_custom_menu_item($item_id, $item, $depth, $args) {
	?>
	<p class="description description-wide">
		<label for="edit-menu-item-icon-<?php echo $item_id; ?>">
			FansPaysite Icon Class (Font Awesome)<br>
			<input type="text" class="icon-picker" name="menu-item-icon[<?php echo $item_id; ?>]" id="edit-menu-item-icon-<?php echo $item_id; ?>" value="<?php echo esc_attr($item->icon); ?>" />
		</label>
	</p>
	<?php
}

add_action('wp_nav_menu_item_custom_fields', 'fanspaysite_custom_menu_item', 10, 4);

function fanspaysite_save_menu_item($menu_id, $menu_item_db_id, $menu_item_args) {
	// Check if element is properly sent
	if (is_array($_REQUEST['menu-item-icon'] ?? false)) {
		$icon_value = $_REQUEST['menu-item-icon'][$menu_item_db_id];
		update_post_meta($menu_item_db_id, '_menu_item_icon', $icon_value);
	}
}
add_action('wp_update_nav_menu_item', 'fanspaysite_save_menu_item', 10, 3);

function fanspaysite_nav_item($menu_item) {
	$menu_item->icon = get_post_meta($menu_item->ID, '_menu_item_icon', true);
	return $menu_item;
}
add_filter('wp_setup_nav_menu_item', 'fanspaysite_nav_item');


function fanspaysite_register_nav_menu() {
	register_nav_menus(array(
		'menu-1' => esc_html__('Primary', 'fanspaysite'),
	));
}
add_action('after_setup_theme', 'fanspaysite_register_nav_menu');



class FansPaysite_Custom_Walker_Nav_Menu extends Walker_Nav_Menu {

	protected static $icon_mapping = array(
		'Webcams' => 'fas fa-video',
		'Channels' => 'fas fa-video',
		'Videos' => 'fab fa-youtube',
		'My Videos' => 'fas fa-file-video',
		'Content' =>'fas fa-file',
		'My Assets' => 'fas fa-boxes',
		'My Subscriptions' => 'fas fa-user-lock',
		'Setup Subscriptions'=> 'fas fa-lock',
		'My Content' =>'fas fa-copy',
		'Downloads' => 'fas fa-copy',
		'Pictures' => 'fas fa-images',
		'Random Room' => 'fas fa-dice-six',
		'Random Videochat' => 'fas fa-dice',
		'Random Cam' => 'fas fa-dice',
		'Random Match' => 'fas fa-dice',
		'Video Calls' => 'fas fa-video',
		'Guest Upload' => 'fas fa-upload',
		'Guest Picture' => 'fas fa-upload',
		'Upload Video' => 'fas fa-upload',
		'Add Download' => 'fas fa-upload',
		'Upload Pictures' => 'fas fa-upload',
		'Content Upload' => 'fas fa-file-upload',
		'Add Recording' => 'fas fa-video',
		'My Wallet' => 'fas fa-wallet',
		'Performer Dashboard' => 'fas fa-toolbox',
		'Broadcast Live' => 'fas fa-toolbox',
		'Studio Dashboard' => 'fas fa-toolbox',
		'Client Dashboard' => 'fas fa-tachometer-alt',
		'Client' => 'fas fa-user',
		'Creator' => 'fas fa-user-md',
		'Creators' => 'fas fa-user-md',
		'Register' =>'fas fa-user-plus',
		'Register Client' =>'fas fa-user-plus',
		'Register Performer' =>'fas fa-user-plus',
		'Register Studio' =>'fas fa-user-plus',
		'Login' => 'fas fa-sign-in-alt',
		'Privacy Policy' => 'fas fa-clipboard-list',
		'Terms of Use' => 'fas fa-clipboard-list',
		'Support' => 'fas fa-comment',
		'Support (Demo)' => 'fas fa-comment',
		'My Conversations' => 'fas fa-comments',
		'Forum' => 'far fa-comments',
		'Match Criteria' => 'fas fa-cog',
		'Membership' => 'fas fa-lock',
		'Settings' => 'fas fa-cog',
		'Cart' => 'fas fa-shopping-cart',
		'News Feed' => 'far fa-newspaper',
		'Activity' => 'far fa-newspaper',
		'Groups' => 'fas fa-users',
		'Users' => 'fas fa-user',
		'Start Own Site' => 'fas fa-shopping-cart',
		// Add more mappings as needed
	);

	// Method for starting a new level
	function start_lvl(&$output, $depth = 0, $args = null) {
		$indent = str_repeat("\t", $depth);
		$output .= "\n$indent<ul class=\"dropdown-menu\">\n";
	}

	// Method for ending a level
	function end_lvl(&$output, $depth = 0, $args = null) {
		$indent = str_repeat("\t", $depth);
		$output .= "$indent</ul>\n";
	}

	// Method for starting a new element
	function start_el(&$output, $item, $depth = 0, $args = null, $id = 0) {
		$indent = ($depth) ? str_repeat("\t", $depth) : '';

		$li_attributes = '';
		$class_names = '';
		$classes = empty($item->classes) ? array() : (array) $item->classes;

		// Add 'nav-item' class to all menu items
		$classes[] = 'nav-item';

		// Check for 'menu-item-has-children' class to add 'dropdown' class for Bootstrap
		if (in_array('menu-item-has-children', $classes)) {
			$classes[] = 'dropdown';
			$li_attributes .= ' aria-haspopup="true" aria-expanded="false"'; // ARIA for accessibility
		}


		if (is_array($args)) {
			$args = (object) $args;
		}

		$class_names = join(' ', apply_filters('nav_menu_css_class', array_filter($classes), $item, $args, $depth));
		$class_names = ' class="' . esc_attr($class_names) . '"';

		$output .= $indent . '<li' . $class_names . $li_attributes .'>';

		$atts = array();
		$atts['href'] = !empty($item->url) ? $item->url : '';

// Additional handling for menu items with children
		if (in_array('menu-item-has-children', $classes)) {
			$atts['data-bs-toggle'] = 'dropdown';
			$atts['aria-expanded']  = 'false';
			$atts['class']          = 'dropdown-toggle nav-link';
			$atts['role']           = 'button'; // ARIA role
			$atts['tabindex']       = '0'; // Make sure it's focusable
		} else {
			$atts['class'] = 'nav-link';
		}

		$attributes = '';
		foreach ($atts as $attr => $value) {
			if (!empty($value)) {
				$attributes .= ' ' . $attr . '="' . esc_attr($value) . '"';
			}
		}

		// Icon or first letter logic
		$icon_class = get_post_meta($item->ID, '_menu_item_icon', true);
		$title = !empty($item->title) ? $item->title : (!empty($item->post_title) ? $item->post_title : 'No Title');

		// Use the icon mapping if no specific icon class is provided and there's an exact match
		if (empty($icon_class) && array_key_exists($title, self::$icon_mapping)) {
			$icon_class = self::$icon_mapping[$title];
		}

		$icon_html = !empty($icon_class) ? "<i class='" . esc_attr($icon_class) . "'></i> " : "<span class='menu-item-icon-letter'>" . esc_html(mb_substr($title, 0, 1)) . "</span> ";

		$item_output = "<a{$attributes} title='" . esc_attr($title) . "'>";
		$item_output .= $icon_html . '<span class="menu-item-title">'. $title . '</span>';
		$item_output .= '</a>';

		$output .= apply_filters('walker_nav_menu_start_el', $item_output, $item, $depth, $args);
	}

	// Method for ending an element
	function end_el(&$output, $item, $depth = 0, $args = null) {
		$output .= "</li>\n";
	}
}