<?php

// Theme Mode settings
function fanspaysite_add_user_theme_mode_field($user) {
	$user_theme_mode = get_user_meta($user->ID, 'fanspaysite_user_theme_mode', true);
	?>
	<h3><?php _e('Theme Mode', 'fanspaysite'); ?></h3>
	<table class="form-table">
		<tr>
			<th><label for="fanspaysite_user_theme_mode"><?php _e('Theme Mode', 'fanspaysite'); ?></label></th>
			<td>
				<select name="fanspaysite_user_theme_mode" id="fanspaysite_user_theme_mode">
					<option value=""><?php _e('Use Site Default', 'fanspaysite'); ?></option>
					<option value="light" <?php selected($user_theme_mode, 'light'); ?>><?php _e('Light', 'fanspaysite'); ?></option>
					<option value="dark" <?php selected($user_theme_mode, 'dark'); ?>><?php _e('Dark', 'fanspaysite'); ?></option>
					<option value="auto" <?php selected($user_theme_mode, 'auto'); ?>><?php _e('Auto', 'fanspaysite'); ?></option>
				</select>
			</td>
		</tr>
	</table>
	<?php
}
add_action('show_user_profile', 'fanspaysite_add_user_theme_mode_field');
add_action('edit_user_profile', 'fanspaysite_add_user_theme_mode_field');

function fanspaysite_save_user_theme_mode($user_id) {
	if (!current_user_can('edit_user', $user_id)) {
		return false;
	}
	update_user_meta($user_id, 'fanspaysite_user_theme_mode', $_POST['fanspaysite_user_theme_mode']);
}
add_action('personal_options_update', 'fanspaysite_save_user_theme_mode');
add_action('edit_user_profile_update', 'fanspaysite_save_user_theme_mode');

function fanspaysite_apply_theme_mode() {
	// Use the helper function to get the current theme mode
	$theme_mode = fanspaysite_get_current_theme_mode();

	// JavaScript function to apply the theme mode
	echo '<script>
	function setConfiguredTheme(theme) {
		if (theme === "auto") {
			if (window.matchMedia && window.matchMedia("(prefers-color-scheme: dark)").matches) {
				document.body.dataset.theme = "dark";
			} else {
				document.body.dataset.theme = "";
			}
		} else {
			document.body.dataset.theme = theme;
		}

		if (document.body.dataset.theme == "dark")
		{
		 jQuery("body").find(".ui").addClass("inverted");
		 jQuery("body").addClass("inverted");
		}else
		{
			jQuery("body").find(".ui").removeClass("inverted");
			jQuery("body").removeClass("inverted");
		}

		console.log("setConfiguredTheme:", theme);
	}



	document.addEventListener("DOMContentLoaded", function() {
		setConfiguredTheme("' . esc_js($theme_mode) . '");
	});

	</script>';
}
add_action('wp_footer', 'fanspaysite_apply_theme_mode');

// Enqueue the script for handling the theme switch
function fanspaysite_enqueue_theme_switch_script() {

	//prevent caching
	$scriptUrl = get_template_directory_uri() . '/js/theme.js';
	$scriptPath = get_template_directory() . '/js/theme.js';
	wp_enqueue_script('fanspaysite-theme-switch',  $scriptUrl, array('jquery'), @filemtime($scriptPath) ?? 1, true);

	// Pass the current theme mode to the script
	wp_localize_script('fanspaysite-theme-switch', 'fanspaysiteThemeSwitch', array(
		'ajax_url' => admin_url('admin-ajax.php'),
		'current_mode' => fanspaysite_get_current_theme_mode(),
		'nonce' => wp_create_nonce('fanspaysite-theme-switch-nonce'),
	));
}
add_action('wp_enqueue_scripts', 'fanspaysite_enqueue_theme_switch_script');

// Helper function to get the current theme mode
function fanspaysite_get_current_theme_mode() {

	// Get user-specific theme mode if logged in
	if (is_user_logged_in()) {
		$user_theme_mode = get_user_meta(get_current_user_id(), 'fanspaysite_user_theme_mode', true);
		if ($user_theme_mode ?? false) {
			return $user_theme_mode;
		}
	}

	// Check for a theme mode set in a cookie for non-logged-in users
	if (isset($_COOKIE['fanspaysite_user_theme_mode'])) {
		$cookie_theme_mode = sanitize_text_field($_COOKIE['fanspaysite_user_theme_mode']);
		if (!empty($cookie_theme_mode)) {
			return $cookie_theme_mode;
		}
	}

	// Fallback to the site-wide default theme mode
	return get_theme_mod('fanspaysite_default_theme_mode', 'light') ;
}

// AJAX action to update user theme mode
function fanspaysite_update_theme_mode() {
	check_ajax_referer('fanspaysite-theme-switch-nonce', 'nonce');

	$mode = isset($_POST['mode']) ? sanitize_text_field($_POST['mode']) : 'light'; // Default to light mode if not set.

	if (!is_user_logged_in()) {
		// Set a cookie for non-logged-in users to remember the theme mode.
		$cookie_name = 'fanspaysite_user_theme_mode';
		$cookie_value = $mode;
		$expire = time() + (86400 * 30); // 30 days from now.
		$path = '/'; // Available site-wide.

		setcookie($cookie_name, $cookie_value, $expire, $path, COOKIE_DOMAIN, is_ssl(), true);

		wp_send_json(array(
			'success' => true,
			'message' => 'Theme mode saved in a cookie.'
		));
		return;
	}

	// For logged-in users, update user meta.
	update_user_meta(get_current_user_id(), 'fanspaysite_user_theme_mode', $mode);

	wp_send_json_success('Theme mode updated for user: ' . esc_attr($mode));
}
add_action('wp_ajax_fanspaysite_update_theme_mode', 'fanspaysite_update_theme_mode'); // For logged-in users.
add_action('wp_ajax_nopriv_fanspaysite_update_theme_mode', 'fanspaysite_update_theme_mode'); // For not logged-in users.
