document.addEventListener("DOMContentLoaded", function () {
  const lightModeBtn = document.getElementById("light-mode");
  const darkModeBtn = document.getElementById("dark-mode");
  const autoModeBtn = document.getElementById("auto-mode");

  function setTheme(theme) {
    if (theme === "auto") {
      if (
        window.matchMedia &&
        window.matchMedia("(prefers-color-scheme: dark)").matches
      ) {
        document.body.dataset.theme = "dark";
      } else {
        document.body.dataset.theme = "";
      }
    } else {
      document.body.dataset.theme = theme;
    }

    if (document.body.dataset.theme == "dark") {
      jQuery("body").find(".ui").addClass("inverted");
      jQuery("body").addClass("inverted");
    } else {
      jQuery("body").find(".ui").removeClass("inverted");
      jQuery("body").removeClass("inverted");
    }

    console.log("setTheme", theme);
  }

  lightModeBtn.addEventListener("click", function () {
    setTheme("light");
  });
  darkModeBtn.addEventListener("click", function () {
    setTheme("dark");
  });
  autoModeBtn.addEventListener("click", function () {
    setTheme("auto");
  });
});

jQuery(document).ready(function ($) {
  // Highlight the current mode button
  $("#" + fanspaysiteThemeSwitch.current_mode + "-mode").addClass("active");

  // Handle click events
  $(".btn-group .btn").click(function () {
    var mode = this.id.replace("-mode", "");
    $(".btn-group .btn").removeClass("active");
    $(this).addClass("active");

    // Update user setting via AJAX if logged in
    $.ajax({
      url: fanspaysiteThemeSwitch.ajax_url,
      type: "POST",
      data: {
        action: "fanspaysite_update_theme_mode",
        mode: mode,
        nonce: fanspaysiteThemeSwitch.nonce,
      },
      success: function (response) {
        if (response.warning) {
          console.warn(response.message); // Or display it in the UI as needed.
        } else {
          console.log("Theme mode updated.");
        }
      },
    });
  });
});
